@@ -13,12 +13,4 @@
 
 ALTER TABLE SUBAWARD_TEMPLATE_INFO
   ADD COLUMN (
-  DATA_SHARING_CD VARCHAR(4));
-
-ALTER TABLE SUBAWARD_TEMPLATE_INFO
-  ADD COLUMN (
-  IRB_IACUC_CONTACT DECIMAL(3, 0));
-
-UPDATE subaward_forms
-SET form = NULL
-WHERE FORM_ID = 'FDP_ATT_3A';
+  FINAL_STATEMENT_DUE_CD VARCHAR(4));
