@@ -11,7 +11,4 @@
 -- #L%
 -- -
 
-DELIMITER /
-ALTER TABLE NOTIFICATION_TYPE_RECIPIENT ADD ROLE_SUB_QUALIFIER VARCHAR(25)
-/
-DELIMITER ;
+ALTER TABLE NOTIFICATION_TYPE_RECIPIENT CHANGE ROLE_ID ROLE_NAME VARCHAR(125) NOT NULL;
